@@ -55,11 +55,26 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
 
+  it('should execute with synchronous iterator', function(done) {
+    var collection = [1, 3, 2];
+    var iterator = function(value, done) {
+      done();
+    };
+    var called = 0;
+    async.each(collection, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      setTimeout(done, delay);
+    });
+  });
+
   it('should execute iterator by collection of array with passing index', function(done) {
 
     var order = [];
@@ -68,7 +83,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1]
@@ -89,7 +104,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -106,7 +121,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [2, 'c'],
         [3, 'b']
@@ -126,7 +141,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -141,7 +156,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1]
@@ -150,6 +165,64 @@ parallel('#each', function() {
     });
   });
 
+  it('should work properly even if elements are added in callback', function(done) {
+
+    var order = [];
+    var arr = [1, 3, 2];
+    var set = new util.Set(arr);
+    var iterator = function(value, next) {
+      order.push(value);
+      next(null, value);
+    };
+    async.each(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      setTimeout(function() {
+        assert.deepStrictEqual(order, arr);
+        done();
+      }, delay);
+      set.add(4);
+    });
+  });
+
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.each(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.each(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator by collection of Map', function(done) {
 
     var order = [];
@@ -161,7 +234,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 2],
         ['b', 3]
@@ -180,7 +253,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['c', 2], 2],
         [['b', 3], 1]
@@ -202,7 +275,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1.1, 2.7, 3.5]);
+      assert.deepStrictEqual(order, [1.1, 2.7, 3.5]);
       done();
     }, Math);
   });
@@ -220,7 +293,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1.1, 'a'],
         [2.7, 'c'],
         [3.5, 'b']
@@ -242,7 +315,7 @@ parallel('#each', function() {
 
     async.each(collection, iterator, function(err) {
       assert.ok(err);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -313,7 +386,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -326,7 +399,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -339,7 +412,20 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
+      done();
+    });
+  });
+
+  it('should return response immediately if a set instance is empty', function(done) {
+
+    var order = [];
+    var set = new util.Set();
+    async.each(set, eachIterator(order), function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -351,7 +437,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -363,7 +449,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -375,7 +461,7 @@ parallel('#each', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -393,7 +479,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -407,7 +493,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2]
@@ -428,7 +514,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -445,7 +531,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'b'],
         [2, 'c']
@@ -465,7 +551,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -480,7 +566,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2]
@@ -489,6 +575,64 @@ parallel('#eachSeries', function() {
     });
   });
 
+  it('should work properly even if elements are added in callback', function(done) {
+
+    var order = [];
+    var arr = [1, 3, 2];
+    var set = new util.Set(arr);
+    var iterator = function(value, next) {
+      order.push(value);
+      next(null, value);
+    };
+    async.eachSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      setTimeout(function() {
+        assert.deepStrictEqual(order, arr);
+        done();
+      }, delay);
+      set.add(4);
+    });
+  });
+
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.eachSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.eachSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator to series by collection of Map', function(done) {
 
     var order = [];
@@ -500,7 +644,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['b', 3],
         ['c', 2]
@@ -519,7 +663,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['b', 3], 1],
         [['c', 2], 2]
@@ -541,7 +685,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1.1, 3.5, 2.7]);
+      assert.deepStrictEqual(order, [1.1, 3.5, 2.7]);
       done();
     }, Math);
   });
@@ -580,7 +724,7 @@ parallel('#eachSeries', function() {
 
     async.eachSeries(collection, iterator, function(err) {
       assert.ok(err);
-      assert.deepEqual(order, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3]);
       done();
     });
   });
@@ -623,7 +767,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3]);
       done();
     });
   });
@@ -636,7 +780,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -649,7 +793,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -661,7 +805,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -673,7 +817,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -685,7 +829,7 @@ parallel('#eachSeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -725,7 +869,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -739,7 +883,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -764,7 +908,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -783,7 +927,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'c'],
         [5, 'b'],
@@ -807,7 +951,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -824,7 +968,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -835,6 +979,144 @@ parallel('#eachLimit', function() {
     });
   });
 
+  it('should work properly even if elements are added in callback', function(done) {
+
+    var order = [];
+    var arr = [1, 5, 3, 4, 2];
+    var set = new util.Set(arr);
+    var iterator = function(value, next) {
+      order.push(value);
+      next(null, value);
+    };
+    async.eachLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      setTimeout(function() {
+        assert.deepStrictEqual(order, arr);
+        done();
+      }, delay);
+      set.add(6);
+    });
+  });
+
+  it('should work with odd number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.eachLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.eachLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.eachLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
+  it('should work with odd number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(value, index, next) {
+      order.push([index, value]);
+      set.delete(value + 1);
+      next();
+    };
+    async.eachLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [[0, 1], [1, 3], [2, 5]]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(value, index, next) {
+      order.push([index, value]);
+      set.delete(value + 1);
+      next();
+    };
+    async.eachLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [[0, 1], [1, 3], [2, 5]]);
+      done();
+    });
+  });
+
+  it('should work even if limit is less than set size', function(done) {
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2]);
+    var iterator = function(value, next) {
+      order.push(value);
+      next();
+    };
+    async.eachLimit(set, 10, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 2]);
+      done();
+    });
+  });
+
   it('should execute iterator in limited by collection of Map', function(done) {
 
     var order = [];
@@ -848,7 +1130,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 3],
         ['b', 5],
@@ -871,7 +1153,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [ ['a', 1], 0],
         [ ['c', 3], 2],
         [ ['b', 5], 1],
@@ -895,7 +1177,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1.1, 3.5, 2.7]);
+      assert.deepStrictEqual(order, [1.1, 3.5, 2.7]);
       done();
     }, Math);
   });
@@ -910,7 +1192,7 @@ parallel('#eachLimit', function() {
         return done(err);
       }
 
-      assert.deepEqual(order, [1, 2, 3, 3, 4]);
+      assert.deepStrictEqual(order, [1, 2, 3, 3, 4]);
       done();
     });
   });
@@ -945,7 +1227,7 @@ parallel('#eachLimit', function() {
 
     async.eachLimit(collection, 3, iterator, function(err) {
       assert.ok(err);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -988,7 +1270,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -1001,7 +1283,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1014,7 +1296,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1026,7 +1308,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1038,7 +1320,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1050,7 +1332,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1063,7 +1345,7 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1076,9 +1358,32 @@ parallel('#eachLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
 
+  it('should work with generator', function(done) {
+    var limit = 2;
+    var collection = ['abc', 'def', 'ghi', 'jkl'];
+    var order = [];
+    var gen = util.makeGenerator(collection);
+
+    async.eachLimit(
+      gen,
+      limit,
+      function(v, i, cb) {
+        order.push(i);
+        setTimeout(cb, Math.random() * delay, null, v);
+      },
+      function(err) {
+        if (err) {
+          return done();
+        }
+        assert.deepStrictEqual(order, [0, 1, 2, 3]);
+        done();
+      }
+    );
+  });
+
 });
