@@ -59,8 +59,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 2);
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [1, 2, 3, 4]);
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3, 4]);
       done();
     });
   });
@@ -75,8 +75,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 2);
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1],
@@ -100,8 +100,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [3]);
-      assert.deepEqual(order, [2, 3, 4]);
+      assert.deepStrictEqual(res, [3]);
+      assert.deepStrictEqual(order, [2, 3, 4]);
       done();
     });
   });
@@ -120,8 +120,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [3]);
+      assert.deepStrictEqual(order, [
         [2, 'c'],
         [3, 'b'],
         [4, 'a']
@@ -143,8 +143,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [3]);
-      assert.deepEqual(order, [2, 3, 4]);
+      assert.deepStrictEqual(res, [3]);
+      assert.deepStrictEqual(order, [2, 3, 4]);
       done();
     });
   });
@@ -162,8 +162,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [3]);
+      assert.deepStrictEqual(order, [
         [2, 2],
         [3, 1],
         [4, 0]
@@ -172,6 +172,43 @@ parallel('#filter', function() {
     });
   });
 
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.filter(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.filter(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator by collection of Map', function(done) {
 
     var order = [];
@@ -185,8 +222,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [['b', 3]]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [['b', 3]]);
+      assert.deepStrictEqual(order, [
         ['c', 2],
         ['b', 3],
         ['a', 4]
@@ -208,8 +245,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [['b', 3]]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [['b', 3]]);
+      assert.deepStrictEqual(order, [
         [['c', 2], 2],
         [['b', 3], 1],
         [['a', 4], 0]
@@ -232,8 +269,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1.1, 3.5, 2.6]);
-      assert.deepEqual(order, [1.1, 2.6, 3.5]);
+      assert.deepStrictEqual(res, [1.1, 3.5, 2.6]);
+      assert.deepStrictEqual(order, [1.1, 2.6, 3.5]);
       done();
     }, Math);
   });
@@ -303,7 +340,7 @@ parallel('#filter', function() {
           }
           assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
           assert.strictEqual(res.length, 0);
-          assert.deepEqual(res, []);
+          assert.deepStrictEqual(res, []);
         });
       });
   });
@@ -352,7 +389,7 @@ parallel('#filter', function() {
       called = true;
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 2);
-      assert.deepEqual(res, ['dir1', 'dir2']);
+      assert.deepStrictEqual(res, ['dir1', 'dir2']);
       setImmediate(done);
     });
   });
@@ -366,8 +403,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -381,8 +418,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -396,8 +433,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -411,8 +448,8 @@ parallel('#filter', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -430,8 +467,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 2);
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [1, 3, 2, 4]);
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3, 2, 4]);
       done();
     });
   });
@@ -446,8 +483,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 2);
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2],
@@ -471,8 +508,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 2);
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -491,8 +528,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 2);
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'b'],
         [2, 'c']
@@ -514,8 +551,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [3]);
-      assert.deepEqual(order, [4, 3, 2]);
+      assert.deepStrictEqual(res, [3]);
+      assert.deepStrictEqual(order, [4, 3, 2]);
       done();
     });
   });
@@ -533,8 +570,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [3]);
+      assert.deepStrictEqual(order, [
         [4, 0],
         [3, 1],
         [2, 2]
@@ -543,6 +580,43 @@ parallel('#filterSeries', function() {
     });
   });
 
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.filterSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.filterSeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator to series by collection of Map', function(done) {
 
     var order = [];
@@ -556,8 +630,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [['b', 3]]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [['b', 3]]);
+      assert.deepStrictEqual(order, [
         ['a', 4],
         ['b', 3],
         ['c', 2]
@@ -579,8 +653,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 1);
-      assert.deepEqual(res, [['b', 3]]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [['b', 3]]);
+      assert.deepStrictEqual(order, [
         [['a', 4], 0],
         [['b', 3], 1],
         [['c', 2], 2]
@@ -604,8 +678,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1.1, 3.5, 2.6]);
-      assert.deepEqual(order, [1.1, 3.5, 2.6]);
+      assert.deepStrictEqual(res, [1.1, 3.5, 2.6]);
+      assert.deepStrictEqual(order, [1.1, 3.5, 2.6]);
       done();
     }, Math);
   });
@@ -626,7 +700,7 @@ parallel('#filterSeries', function() {
         return done(err);
       }
       assert.strictEqual(sync, false);
-      assert.deepEqual(res, [1, 3, 2]);
+      assert.deepStrictEqual(res, [1, 3, 2]);
       done();
     });
     sync = false;
@@ -704,8 +778,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -719,8 +793,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -734,8 +808,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -749,8 +823,8 @@ parallel('#filterSeries', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -770,8 +844,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1, 5, 3]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 5, 3]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -787,8 +861,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1, 5, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 5, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -815,8 +889,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1, 5, 3]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 5, 3]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -837,8 +911,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1, 5, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 5, 3]);
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'c'],
         [5, 'b'],
@@ -864,8 +938,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1, 5, 3]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 5, 3]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -885,8 +959,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1, 5, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 5, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -897,6 +971,65 @@ parallel('#filterLimit', function() {
     });
   });
 
+  it('should work with odd number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(value, index, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.filterLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(value, index, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.filterLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.filterLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator in limited by collection of Map', function(done) {
 
     var order = [];
@@ -912,12 +1045,12 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['b', 5],
         ['c', 3]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 3],
         ['b', 5],
@@ -943,12 +1076,12 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['b', 5],
         ['c', 3]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['c', 3], 2],
         [['b', 5], 1],
@@ -973,8 +1106,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 3);
-      assert.deepEqual(res, [1.1, 3.5, 2.7]);
-      assert.deepEqual(order, [1.1, 3.5, 2.7]);
+      assert.deepStrictEqual(res, [1.1, 3.5, 2.7]);
+      assert.deepStrictEqual(order, [1.1, 3.5, 2.7]);
       done();
     }, Math);
   });
@@ -990,8 +1123,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 4);
-      assert.deepEqual(res, [1, 3, 3, 1]);
-      assert.deepEqual(order, [1, 1, 2, 3, 3, 4]);
+      assert.deepStrictEqual(res, [1, 3, 3, 1]);
+      assert.deepStrictEqual(order, [1, 1, 2, 3, 3, 4]);
       done();
     });
   });
@@ -1008,7 +1141,7 @@ parallel('#filterLimit', function() {
         return done(err);
       }
       assert.strictEqual(sync, false);
-      assert.deepEqual(res, [1, 3, 3, 1]);
+      assert.deepStrictEqual(res, [1, 3, 3, 1]);
       done();
     });
     sync = false;
@@ -1028,7 +1161,7 @@ parallel('#filterLimit', function() {
     async.filterLimit(collection, 2, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1]
@@ -1085,7 +1218,7 @@ parallel('#filterLimit', function() {
           }
           assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
           assert.strictEqual(res.length, 0);
-          assert.deepEqual(res, []);
+          assert.deepStrictEqual(res, []);
         });
       });
   });
@@ -1122,8 +1255,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1137,8 +1270,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1152,8 +1285,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1167,8 +1300,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1182,8 +1315,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1198,8 +1331,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1214,8 +1347,8 @@ parallel('#filterLimit', function() {
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
       assert.strictEqual(res.length, 0);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
