@@ -60,12 +60,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -79,12 +79,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1]
@@ -106,12 +106,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2,
         b: 6,
         c: 4
       });
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -129,12 +129,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2,
         b: 6,
         c: 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [2, 'c'],
         [3, 'b']
@@ -155,12 +155,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -176,12 +176,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1]
@@ -190,6 +190,45 @@ parallel('#mapValues', function() {
     });
   });
 
+  it('shoult work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next(null, value);
+    };
+    async.mapValues(set, iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      assert.deepStrictEqual(res, { '0': 1, '1': 3 });
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next(null, value);
+    };
+    async.mapValues(set, iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      assert.deepStrictEqual(res, { '0': 1, '1': 2, '2': 3, '3': 4, '4': 5, '5': 6, '6': 7 });
+      done();
+    });
+  });
+
   it('should execute iterator to series by collection of Map', function(done) {
 
     var order = [];
@@ -202,12 +241,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 2],
         ['b', 3]
@@ -227,12 +266,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['c', 2], 2],
         [['b', 3], 1]
@@ -255,12 +294,12 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2.2,
         b: 7,
         c: 5.4
       });
-      assert.deepEqual(order, [1.1, 2.7, 3.5]);
+      assert.deepStrictEqual(order, [1.1, 2.7, 3.5]);
       done();
     }, Math);
   });
@@ -279,11 +318,11 @@ parallel('#mapValues', function() {
     async.mapValues(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 1,
         '2': 2
       });
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -347,8 +386,8 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -362,8 +401,8 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -376,8 +415,8 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -390,8 +429,8 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -404,8 +443,8 @@ parallel('#mapValues', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -423,12 +462,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -442,12 +481,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2]
@@ -469,12 +508,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2,
         b: 6,
         c: 4
       });
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -492,12 +531,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2,
         b: 6,
         c: 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'b'],
         [2, 'c']
@@ -518,12 +557,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -539,12 +578,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2]
@@ -553,6 +592,45 @@ parallel('#mapValuesSeries', function() {
     });
   });
 
+  it('shoult work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next(null, value);
+    };
+    async.mapValuesSeries(set, iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      assert.deepStrictEqual(res, { '0': 1, '1': 3 });
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next(null, value);
+    };
+    async.mapValuesSeries(set, iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      assert.deepStrictEqual(res, { '0': 1, '1': 2, '2': 3, '3': 4, '4': 5, '5': 6, '6': 7 });
+      done();
+    });
+  });
+
   it('should execute iterator by collection of Map', function(done) {
 
     var order = [];
@@ -565,12 +643,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['b', 3],
         ['c', 2]
@@ -590,12 +668,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['b', 3], 1],
         [['c', 2], 2]
@@ -618,12 +696,12 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2.2,
         b: 7,
         c: 5.4
       });
-      assert.deepEqual(order, [1.1, 3.5, 2.7]);
+      assert.deepStrictEqual(order, [1.1, 3.5, 2.7]);
       done();
     }, Math);
   });
@@ -645,7 +723,7 @@ parallel('#mapValuesSeries', function() {
       }
       assert.strictEqual(sync, false);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 1,
         b: 3,
         c: 2
@@ -669,10 +747,10 @@ parallel('#mapValuesSeries', function() {
     async.mapValuesSeries(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 1
       });
-      assert.deepEqual(order, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3]);
       done();
     });
   });
@@ -736,8 +814,8 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -751,8 +829,8 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -765,8 +843,8 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -779,8 +857,8 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -793,8 +871,8 @@ parallel('#mapValuesSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -813,14 +891,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 10,
         '2': 6,
         '3': 8,
         '4': 4
       });
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -835,14 +913,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 10,
         '2': 6,
         '3': 8,
         '4': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -868,14 +946,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2,
         b: 10,
         c: 6,
         d: 8,
         e: 4
       });
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -895,14 +973,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2,
         b: 10,
         c: 6,
         d: 8,
         e: 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'c'],
         [5, 'b'],
@@ -927,14 +1005,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 10,
         '2': 6,
         '3': 8,
         '4': 4
       });
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -952,14 +1030,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 10,
         '2': 6,
         '3': 8,
         '4': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -970,6 +1048,65 @@ parallel('#mapValuesLimit', function() {
     });
   });
 
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.mapValuesLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
+  it('should work with odd number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(value, index, next) {
+      order.push([index, value]);
+      set.delete(value + 1);
+      next();
+    };
+    async.mapValuesLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [[0, 1], [1, 3], [2, 5]]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(value, index, next) {
+      order.push([index, value]);
+      set.delete(value + 1);
+      next();
+    };
+    async.mapValuesLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [[0, 1], [1, 3], [2, 5]]);
+      done();
+    });
+  });
+
   it('should execute iterator in limited by collection of Map', function(done) {
 
     var order = [];
@@ -984,14 +1121,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 10,
         '2': 6,
         '3': 8,
         '4': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 3],
         ['b', 5],
@@ -1015,14 +1152,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 10,
         '2': 6,
         '3': 8,
         '4': 4
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['c', 3], 2],
         [['b', 5], 1],
@@ -1047,12 +1184,12 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2.2,
         b: 7,
         c: 5.4
       });
-      assert.deepEqual(order, [1.1, 3.5, 2.7]);
+      assert.deepStrictEqual(order, [1.1, 3.5, 2.7]);
       done();
     }, Math);
   });
@@ -1067,14 +1204,14 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 2,
         '1': 6,
         '2': 8,
         '3': 4,
         '4': 6
       });
-      assert.deepEqual(order, [1, 2, 3, 3, 4]);
+      assert.deepStrictEqual(order, [1, 2, 3, 3, 4]);
       done();
     });
   });
@@ -1092,7 +1229,7 @@ parallel('#mapValuesLimit', function() {
       }
       assert.strictEqual(sync, false);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 1,
         '1': 3,
         '2': 4,
@@ -1118,11 +1255,11 @@ parallel('#mapValuesLimit', function() {
     async.mapValuesLimit(collection, 4, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         '0': 1,
         '3': 2
       });
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -1186,8 +1323,8 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1201,8 +1338,8 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1215,8 +1352,8 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1229,8 +1366,8 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1243,8 +1380,8 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1258,8 +1395,8 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1273,8 +1410,8 @@ parallel('#mapValuesLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
