@@ -57,8 +57,8 @@ parallel('#sortBy', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -71,8 +71,8 @@ parallel('#sortBy', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1]
@@ -93,8 +93,8 @@ parallel('#sortBy', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -111,8 +111,8 @@ parallel('#sortBy', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [2, 'c'],
         [3, 'b']
@@ -133,8 +133,8 @@ parallel('#sortBy', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -150,8 +150,8 @@ parallel('#sortBy', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 2],
         [3, 1]
@@ -160,6 +160,43 @@ parallel('#sortBy', function() {
     });
   });
 
+  it('should work even if the size is decreased', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.sortBy(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.sortBy(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator by collection of Map', function(done) {
 
     var order = [];
@@ -172,12 +209,12 @@ parallel('#sortBy', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['c', 2],
         ['b', 3]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 2],
         ['b', 3]
@@ -198,12 +235,12 @@ parallel('#sortBy', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['c', 2],
         ['b', 3]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['c', 2], 2],
         [['b', 3], 1]
@@ -225,12 +262,47 @@ parallel('#sortBy', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1.1, 2.7, 3.5]);
-      assert.deepEqual(order, [1.1, 2.7, 3.5]);
+      assert.deepStrictEqual(res, [1.1, 2.7, 3.5]);
+      assert.deepStrictEqual(order, [1.1, 2.7, 3.5]);
       done();
     }, Math);
   });
 
+  it('should keep the order if criteria are same value', function(done) {
+
+    var collection = [{
+      a: 1, b: 1
+    }, {
+      a: 2, b: 2
+    }, {
+      a: 1, b: 3
+    }, {
+      a: 2, b: 4
+    }, {
+      a: 1, b: 5
+    }];
+    var iterator = function(obj, callback) {
+      callback(null, obj.a);
+    }
+    async.sortBy(collection, iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(res, [{
+        a: 1, b: 1
+      }, {
+        a: 1, b: 3
+      }, {
+        a: 1, b: 5
+      }, {
+        a: 2, b: 2
+      }, {
+        a: 2, b: 4
+      }]);
+      done();
+    });
+  });
+
   it('should throw error', function(done) {
     var order = [];
     var collection = [1, 3, 2];
@@ -243,7 +315,7 @@ parallel('#sortBy', function() {
     async.sortBy(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 2, 3]);
       done();
     });
   });
@@ -301,8 +373,8 @@ parallel('#sortBy', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -314,8 +386,8 @@ parallel('#sortBy', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -327,8 +399,8 @@ parallel('#sortBy', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -345,8 +417,8 @@ parallel('#sortBySeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -359,8 +431,8 @@ parallel('#sortBySeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2]
@@ -381,8 +453,8 @@ parallel('#sortBySeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -399,8 +471,8 @@ parallel('#sortBySeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'b'],
         [2, 'c']
@@ -421,8 +493,8 @@ parallel('#sortBySeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [1, 3, 2]);
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [1, 3, 2]);
       done();
     });
   });
@@ -438,8 +510,8 @@ parallel('#sortBySeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2]
@@ -448,6 +520,25 @@ parallel('#sortBySeries', function() {
     });
   });
 
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.sortBySeries(set, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator to series by collection of Map', function(done) {
 
     var order = [];
@@ -460,12 +551,12 @@ parallel('#sortBySeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['c', 2],
         ['b', 3]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['b', 3],
         ['c', 2]
@@ -485,12 +576,12 @@ parallel('#sortBySeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['c', 2],
         ['b', 3]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['b', 3], 1],
         [['c', 2], 2]
@@ -512,8 +603,8 @@ parallel('#sortBySeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1.1, 2.7, 3.5]);
-      assert.deepEqual(order, [1.1, 3.5, 2.7]);
+      assert.deepStrictEqual(res, [1.1, 2.7, 3.5]);
+      assert.deepStrictEqual(order, [1.1, 3.5, 2.7]);
       done();
     }, Math);
   });
@@ -534,7 +625,7 @@ parallel('#sortBySeries', function() {
         return done(err);
       }
       assert.strictEqual(sync, false);
-      assert.deepEqual(res, [2, 1, 3]);
+      assert.deepStrictEqual(res, [2, 1, 3]);
       done();
     });
     sync = false;
@@ -553,7 +644,7 @@ parallel('#sortBySeries', function() {
     async.sortBySeries(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3]);
       done();
     });
   });
@@ -571,7 +662,7 @@ parallel('#sortBySeries', function() {
     async.sortBySeries(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1]
       ]);
@@ -632,8 +723,8 @@ parallel('#sortBySeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -645,8 +736,8 @@ parallel('#sortBySeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -658,8 +749,8 @@ parallel('#sortBySeries', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -676,8 +767,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3, 4, 5]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 2, 3, 4, 5]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -690,8 +781,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3, 4, 5]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3, 4, 5]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -716,8 +807,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3, 4, 5]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 2, 3, 4, 5]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -736,8 +827,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 2, 3, 4, 5]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3, 4, 5]);
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'c'],
         [5, 'b'],
@@ -762,8 +853,8 @@ parallel('#sortByLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2, 3, 4, 5]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 2, 3, 4, 5]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -781,8 +872,8 @@ parallel('#sortByLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2, 3, 4, 5]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 2, 3, 4, 5]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -793,6 +884,65 @@ parallel('#sortByLimit', function() {
     });
   });
 
+  it('should work with odd number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(value, index, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.sortByLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is decreased', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(value, index, next) {
+      order.push(value);
+      set.delete(value + 1);
+      next();
+    };
+    async.sortByLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work even if the size is increased', function(done) {
+
+    var order = [];
+    var size = 4;
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(value, next) {
+      order.push(value);
+      value % 2 === 0 && set.add(++size);
+      next();
+    };
+    async.sortByLimit(set, 2, iterator, function(err) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5, 6, 7]);
+      done();
+    });
+  });
+
   it('should execute iterator in limited by collection of Map', function(done) {
 
     var order = [];
@@ -807,14 +957,14 @@ parallel('#sortByLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['e', 2],
         ['c', 3],
         ['d', 4],
         ['b', 5]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 3],
         ['b', 5],
@@ -838,14 +988,14 @@ parallel('#sortByLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['e', 2],
         ['c', 3],
         ['d', 4],
         ['b', 5]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['c', 3], 2],
         [['b', 5], 1],
@@ -869,8 +1019,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1.1, 2.7, 3.5]);
-      assert.deepEqual(order, [1.1, 2.7, 3.5]);
+      assert.deepStrictEqual(res, [1.1, 2.7, 3.5]);
+      assert.deepStrictEqual(order, [1.1, 2.7, 3.5]);
       done();
     }, Math);
   });
@@ -883,8 +1033,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, [1, 3, 5]);
-      assert.deepEqual(order, [1, 3, 5]);
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      assert.deepStrictEqual(order, [1, 3, 5]);
       done();
     });
   });
@@ -907,7 +1057,7 @@ parallel('#sortByLimit', function() {
         return done(err);
       }
       assert.strictEqual(sync, false);
-      assert.deepEqual(res, [2, 4, 1, 3, 5]);
+      assert.deepStrictEqual(res, [2, 4, 1, 3, 5]);
       done();
     });
     sync = false;
@@ -926,7 +1076,7 @@ parallel('#sortByLimit', function() {
     async.sortByLimit(collection, 2, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3]);
       done();
     });
   });
@@ -944,7 +1094,7 @@ parallel('#sortByLimit', function() {
     async.sortByLimit(collection, 2, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(res, undefined);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2]
       ]);
@@ -1005,8 +1155,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1018,8 +1168,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1031,8 +1181,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1045,8 +1195,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1059,8 +1209,8 @@ parallel('#sortByLimit', function() {
       if (err) {
         return done(err);
       }
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
