@@ -73,8 +73,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 5]);
-      assert.deepEqual(order, [1, 2, 3, 4, 5]);
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      assert.deepStrictEqual(order, [1, 2, 3, 4, 5]);
       done();
     });
   });
@@ -88,8 +88,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 5]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [2, 3],
         [3, 2],
@@ -113,8 +113,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [3, 5]);
-      assert.deepEqual(order, [2, 3, 5]);
+      assert.deepStrictEqual(res, [3, 5]);
+      assert.deepStrictEqual(order, [2, 3, 5]);
       done();
     });
   });
@@ -132,11 +132,11 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         b: 3,
         a: 5
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 'c'],
         [3, 'b'],
         [5, 'a']
@@ -157,8 +157,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [3, 5]);
-      assert.deepEqual(order, [2, 3, 5]);
+      assert.deepStrictEqual(res, [3, 5]);
+      assert.deepStrictEqual(order, [2, 3, 5]);
       done();
     });
   });
@@ -175,11 +175,11 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         0: 5,
         1: 3
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 2],
         [3, 1],
         [5, 0]
@@ -188,6 +188,49 @@ parallel('#transform', function() {
     });
   });
 
+  it('should work properly even if elements are added in callback', function(done) {
+
+    var order = [];
+    var arr = [1, 3, 2];
+    var set = new util.Set(arr);
+    var iterator = function(acc, value, next) {
+      order.push(value);
+      acc.push(value);
+      next();
+    };
+    async.transform(set, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      setTimeout(function() {
+        assert.deepStrictEqual(order, arr);
+        assert.deepStrictEqual(res, arr);
+        done();
+      }, delay);
+      set.add(4);
+    });
+  });
+
+  it('should work even if the size is changed', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(acc, value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      acc.push(value);
+      next();
+    };
+    async.transform(set, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      assert.deepStrictEqual(res, [1, 3]);
+      done();
+    });
+  });
+
   it('should execute iterator in limited by collection of Map', function(done) {
 
     var order = [];
@@ -200,11 +243,11 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['b', 3],
         ['a', 5]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['c', 2],
         ['b', 3],
         ['a', 5]
@@ -225,11 +268,11 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         0: ['a', 5],
         1: ['b', 3]
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['c', 2], 2],
         [['b', 3], 1],
         [['a', 5], 0]
@@ -254,8 +297,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [2, 3]);
-      assert.deepEqual(order, [2, 3]);
+      assert.deepStrictEqual(res, [2, 3]);
+      assert.deepStrictEqual(order, [2, 3]);
       done();
     });
   });
@@ -275,8 +318,8 @@ parallel('#transform', function() {
       }
 
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [3]);
+      assert.deepStrictEqual(order, [
         [2, 'c'],
         [3, 'b'],
         [3.5, 'break']
@@ -299,8 +342,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, [
         [1.1, 'a'],
         [2.6, 'c'],
         [3.5, 'b']
@@ -323,8 +366,8 @@ parallel('#transform', function() {
     async.transform(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 2, 3, 4]);
-      assert.deepEqual(order, [1, 2, 3, 4]);
+      assert.deepStrictEqual(res, [1, 2, 3, 4]);
+      assert.deepStrictEqual(order, [1, 2, 3, 4]);
       done();
     });
   });
@@ -362,7 +405,7 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -377,7 +420,7 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
+      assert.deepStrictEqual(res, {});
       done();
     });
   });
@@ -390,8 +433,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -404,8 +447,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -418,8 +461,8 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -434,7 +477,7 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
+      assert.deepStrictEqual(res, {});
       done();
     });
   });
@@ -449,7 +492,7 @@ parallel('#transform', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -467,8 +510,8 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [1, 3, 2, 4]);
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3, 2, 4]);
       done();
     });
   });
@@ -482,8 +525,8 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 1],
         [2, 2],
@@ -506,8 +549,8 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [5, 3]);
-      assert.deepEqual(order, [5, 3, 2]);
+      assert.deepStrictEqual(res, [5, 3]);
+      assert.deepStrictEqual(order, [5, 3, 2]);
       done();
     });
   });
@@ -525,11 +568,11 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 5,
         b: 3
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [5, 'a'],
         [3, 'b'],
         [2, 'c']
@@ -550,8 +593,8 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [5, 3]);
-      assert.deepEqual(order, [5, 3, 2]);
+      assert.deepStrictEqual(res, [5, 3]);
+      assert.deepStrictEqual(order, [5, 3, 2]);
       done();
     });
   });
@@ -568,11 +611,11 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         0: 5,
         1: 3
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [5, 0],
         [3, 1],
         [2, 2]
@@ -581,6 +624,49 @@ parallel('#transformSeries', function() {
     });
   });
 
+  it('should work properly even if elements are added in callback', function(done) {
+
+    var order = [];
+    var arr = [1, 3, 2];
+    var set = new util.Set(arr);
+    var iterator = function(acc, value, next) {
+      order.push(value);
+      acc.push(value);
+      next();
+    };
+    async.transformSeries(set, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      setTimeout(function() {
+        assert.deepStrictEqual(order, arr);
+        assert.deepStrictEqual(res, arr);
+        done();
+      }, delay);
+      set.add(4);
+    });
+  });
+
+  it('should work even if the size is changed', function(done) {
+
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4]);
+    var iterator = function(acc, value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      acc.push(value);
+      next();
+    };
+    async.transformSeries(set, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.deepStrictEqual(order, [1, 3]);
+      assert.deepStrictEqual(res, [1, 3]);
+      done();
+    });
+  });
+
   it('should execute iterator to series by collection of Map', function(done) {
 
     var order = [];
@@ -593,11 +679,11 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 5],
         ['b', 3]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 5],
         ['b', 3],
         ['c', 2]
@@ -618,11 +704,11 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         0: ['a', 5],
         1: ['b', 3]
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 5], 0],
         [['b', 3], 1],
         [['c', 2], 2]
@@ -645,10 +731,10 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 5
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [5, 'a'],
         [3.5, 'break']
       ]);
@@ -670,8 +756,8 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, [
         [1.1, 'a'],
         [3.5, 'b'],
         [2.6, 'c']
@@ -699,7 +785,7 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(sync, false);
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2,
         b: 6,
         c: 4,
@@ -725,8 +811,8 @@ parallel('#transformSeries', function() {
     async.transformSeries(collection, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 5, 3, 2, 4]);
-      assert.deepEqual(order, [1, 5, 3, 2, 4]);
+      assert.deepStrictEqual(res, [1, 5, 3, 2, 4]);
+      assert.deepStrictEqual(order, [1, 5, 3, 2, 4]);
       done();
     });
   });
@@ -787,7 +873,7 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -802,7 +888,7 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
+      assert.deepStrictEqual(res, {});
       done();
     });
   });
@@ -815,8 +901,8 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -829,8 +915,8 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -843,8 +929,8 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -859,7 +945,7 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
+      assert.deepStrictEqual(res, {});
       done();
     });
   });
@@ -874,7 +960,7 @@ parallel('#transformSeries', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -893,8 +979,8 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 5]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -909,8 +995,8 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 5]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      assert.deepStrictEqual(order, [
         [1, 0],
         [3, 2],
         [5, 1],
@@ -936,8 +1022,8 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3, 5]);
-      assert.deepEqual(order, [1, 3, 5, 2, 4]);
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      assert.deepStrictEqual(order, [1, 3, 5, 2, 4]);
       done();
     });
   });
@@ -957,12 +1043,12 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 1,
         b: 5,
         c: 3
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [1, 'a'],
         [3, 'c'],
         [5, 'b'],
@@ -973,6 +1059,117 @@ parallel('#transformLimit', function() {
     });
   });
 
+  it('should work properly even if elements are added in callback', function(done) {
+
+    var order = [];
+    var arr = [1, 5, 3, 2, 4];
+    var set = new util.Set(arr);
+    var iterator = function(acc, value, next) {
+      order.push(value);
+      acc.push(value);
+      next();
+    };
+    async.transformLimit(set, 2, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      setTimeout(function() {
+        assert.deepStrictEqual(order, arr);
+        assert.deepStrictEqual(res, arr);
+        done();
+      }, delay);
+      set.add(6);
+    });
+  });
+
+  it('should work with odd number of elements even if the size is changed', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(acc, value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      acc.push(value);
+      next();
+    };
+    async.transformLimit(set, 2, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is changed', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(acc, value, next) {
+      order.push(value);
+      set.delete(value + 1);
+      acc.push(value);
+      next();
+    };
+    async.transformLimit(set, 2, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [1, 3, 5]);
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work with odd number of elements even if the size is changed', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5]);
+    var iterator = function(acc, value, index, next) {
+      order.push([index, value]);
+      set.delete(value + 1);
+      acc.push(value);
+      next();
+    };
+    async.transformLimit(set, 2, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [[0, 1], [1, 3], [2, 5]]);
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      done();
+    });
+  });
+
+  it('should work with even number of elements even if the size is changed', function(done) {
+
+    var called = 0;
+    var order = [];
+    var set = new util.Set([1, 2, 3, 4, 5, 6]);
+    var iterator = function(acc, value, index, next) {
+      order.push([index, value]);
+      set.delete(value + 1);
+      acc.push(value);
+      next();
+    };
+    async.transformLimit(set, 2, [], iterator, function(err, res) {
+      if (err) {
+        return done(err);
+      }
+      assert.strictEqual(++called, 1);
+      assert.deepStrictEqual(order, [[0, 1], [1, 3], [2, 5]]);
+      assert.deepStrictEqual(res, [1, 3, 5]);
+      done();
+    });
+  });
+
   it('should execute iterator in limited by collection of Map', function(done) {
 
     var order = [];
@@ -987,12 +1184,12 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [
+      assert.deepStrictEqual(res, [
         ['a', 1],
         ['c', 3],
         ['b', 5]
       ]);
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         ['a', 1],
         ['c', 3],
         ['b', 5],
@@ -1017,12 +1214,12 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         0: ['a', 1],
         1: ['b', 5],
         2: ['c', 3]
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [['a', 1], 0],
         [['c', 3], 2],
         [['b', 5], 1],
@@ -1048,10 +1245,10 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         b: 3
       });
-      assert.deepEqual(order, [
+      assert.deepStrictEqual(order, [
         [2, 'c'],
         [3, 'b'],
         [3.5, 'break']
@@ -1075,8 +1272,8 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, [1.1, 3.5, 2.7]);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, [1.1, 3.5, 2.7]);
       done();
     }, Math);
   });
@@ -1091,8 +1288,8 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 1, 1, 3, 3]);
-      assert.deepEqual(order, [1, 1, 1, 2, 3, 3, 4]);
+      assert.deepStrictEqual(res, [1, 1, 1, 3, 3]);
+      assert.deepStrictEqual(order, [1, 1, 1, 2, 3, 3, 4]);
       done();
     });
   });
@@ -1116,7 +1313,7 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(sync, false);
-      assert.deepEqual(res, {
+      assert.deepStrictEqual(res, {
         a: 2,
         b: 6,
         c: 4,
@@ -1142,8 +1339,8 @@ parallel('#transformLimit', function() {
     async.transformLimit(collection, 2, iterator, function(err, res) {
       assert.ok(err);
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, [1, 3]);
-      assert.deepEqual(order, [1, 3]);
+      assert.deepStrictEqual(res, [1, 3]);
+      assert.deepStrictEqual(order, [1, 3]);
       done();
     });
   });
@@ -1181,7 +1378,7 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
@@ -1196,7 +1393,7 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
+      assert.deepStrictEqual(res, {});
       done();
     });
   });
@@ -1209,8 +1406,8 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1223,8 +1420,8 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1237,8 +1434,8 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(res, {});
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1252,9 +1449,9 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(order, []);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1268,9 +1465,9 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(order, []);
-      assert.deepEqual(res, []);
-      assert.deepEqual(order, []);
+      assert.deepStrictEqual(order, []);
+      assert.deepStrictEqual(res, []);
+      assert.deepStrictEqual(order, []);
       done();
     });
   });
@@ -1285,7 +1482,7 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Object]');
-      assert.deepEqual(res, {});
+      assert.deepStrictEqual(res, {});
       done();
     });
   });
@@ -1300,7 +1497,7 @@ parallel('#transformLimit', function() {
         return done(err);
       }
       assert.strictEqual(Object.prototype.toString.call(res), '[object Array]');
-      assert.deepEqual(res, []);
+      assert.deepStrictEqual(res, []);
       done();
     });
   });
